.. coral documentation master file, created by
   sphinx-quickstart on Tue Sep 24 18:33:33 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to coral
=================================

:Author: Nick Bolten
:Source code: `github.com project <http://github.com/klavinslab/coral>`_
:Issue Tracker: `github.com issues <http://github.com/klavinslab/coral/issues>`_
:Generated: |today|
:License: Academic (UW License, see LICENSE in source)
:Version: |release|

**Tutorial:**

.. toctree::
   :maxdepth: 3

   tutorial/index

**API Documentation:**

.. toctree::
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
